==> opie.i18n_anoncvs.handhelds.org_v1_2_1_.tar.gz: i18n/ru/bluetooth-manager.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>BlueBase</name>
    <message>
        <source>Bluetooth Manager</source>
        <translation>Менеджер Bluetooth</translation>
    </message>
    <message>
        <source>&lt;b&gt;Device name : &lt;/b&gt; Ipaq</source>
        <translation>&lt;b&gt;Имя устройства : &lt;/b&gt; Ipaq</translation>
    </message>
    <message>
        <source>MAC adress: </source>
        <translation>MAC адрес:</translation>
    </message>
    <message>
        <source>Class</source>
        <translation>Класс</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Тест</translation>
    </message>
    <message>
        <source>Changes were applied.</source>
        <translation>Изменения применены.</translation>
    </message>
    <message>
        <source>rescan sevices</source>
        <translation type="obsolete">просканировать сервисы</translation>
    </message>
    <message>
        <source>to group</source>
        <translation type="obsolete">в группу</translation>
    </message>
    <message>
        <source>delete</source>
        <translation type="obsolete">удалить</translation>
    </message>
    <message>
        <source>Test1:</source>
        <translation>Тест1:</translation>
    </message>
    <message>
        <source>no services found</source>
        <translation>сервисов не найдено</translation>
    </message>
    <message>
        <source>No connections found</source>
        <translation>Не найдено соединений</translation>
    </message>
    <message>
        <source>&amp;Rescan services</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BluetoothBase</name>
    <message>
        <source>Form1</source>
        <translation>Форма1</translation>
    </message>
    <message>
        <source>Devices</source>
        <translation>Устройства</translation>
    </message>
    <message>
        <source>Device Name</source>
        <translation>Имя устройства</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Онлайн</translation>
    </message>
    <message>
        <source>Scan for Devices</source>
        <translation type="obsolete">Просканировать устройства</translation>
    </message>
    <message>
        <source>Connections</source>
        <translation>Соединения</translation>
    </message>
    <message>
        <source>Connection type</source>
        <translation>Тип соединения</translation>
    </message>
    <message>
        <source>Signal</source>
        <translation>Сигнал</translation>
    </message>
    <message>
        <source>Config</source>
        <translation>Настройка</translation>
    </message>
    <message>
        <source>Bluetooh Basic Config</source>
        <translation type="obsolete">Основные настройки Bluetooth</translation>
    </message>
    <message>
        <source>Default Passkey</source>
        <translation>Ключ по умолчанию</translation>
    </message>
    <message>
        <source>enable authentification</source>
        <translation>разрешить аутентификацию</translation>
    </message>
    <message>
        <source>enable encryption</source>
        <translation>разрешить шифрование</translation>
    </message>
    <message>
        <source>Enable Page scan</source>
        <translation type="unfinished">Разрешить Page scan</translation>
    </message>
    <message>
        <source>Enable Inquiry scan</source>
        <translation type="unfinished">Разрешить Inquiry scan</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>Rfcomm Bind Table</source>
        <translation type="obsolete">Таблица привязок Rfcomm</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Status Label</source>
        <translation>Метка статуса</translation>
    </message>
    <message>
        <source>Bluetooth Basic Config</source>
        <translation>Основная настройка Bluetooth</translation>
    </message>
    <message>
        <source>&amp;Rescan Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit RFCOMM Bind Table</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceDialog</name>
    <message>
        <source>Form2</source>
        <translation>Форма2</translation>
    </message>
    <message>
        <source>Devicename</source>
        <translation type="obsolete">Имя устройства</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Сервицы</translation>
    </message>
    <message>
        <source>change settings</source>
        <translation type="obsolete">изменить настройки</translation>
    </message>
    <message>
        <source>active</source>
        <translation>включен</translation>
    </message>
    <message>
        <source>service name</source>
        <translation>имя сервиса</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Change device 
name</source>
        <translation type="obsolete">Изменить имя
устройства</translation>
    </message>
    <message>
        <source>Default PIN 
Code</source>
        <translation type="obsolete">PIN-код по
умолчанию</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>TextLabel9</source>
        <translation>ТекстМетка9</translation>
    </message>
    <message>
        <source>&amp;Apply Changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default PIN Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change device name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DunPopup</name>
    <message>
        <source>connect</source>
        <translation>подключить</translation>
    </message>
    <message>
        <source>connect+conf</source>
        <translation>подключить+конф</translation>
    </message>
    <message>
        <source>disconnect</source>
        <translation>отключить</translation>
    </message>
</context>
<context>
    <name>ObexDialog</name>
    <message>
        <source>beam files </source>
        <translation>отправить файлы</translation>
    </message>
    <message>
        <source>Which file should be beamed?</source>
        <translation>Какие файлы должны быть отправлены?</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Отправить</translation>
    </message>
</context>
<context>
    <name>OpieTooth::ScanDialog</name>
    <message>
        <source>Scan for devices</source>
        <translation>Искать устройства</translation>
    </message>
    <message>
        <source>Start scan</source>
        <translation>Начать поиск</translation>
    </message>
    <message>
        <source>Add Device</source>
        <translation>Добавить устройство</translation>
    </message>
    <message>
        <source>Stop scan</source>
        <translation>Остановить поиск</translation>
    </message>
</context>
<context>
    <name>PPPDialog</name>
    <message>
        <source>ppp connection </source>
        <translation>ppp соединение</translation>
    </message>
    <message>
        <source>Enter an ppp script name:</source>
        <translation>Введите имя скрипта ppp:</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Подключиться</translation>
    </message>
</context>
<context>
    <name>PanPopup</name>
    <message>
        <source>connect</source>
        <translation>подключить</translation>
    </message>
    <message>
        <source>connect+conf</source>
        <translation>подключить+конф</translation>
    </message>
    <message>
        <source>disconnect</source>
        <translation>отключить</translation>
    </message>
</context>
<context>
    <name>RfcommAssignDialogBase</name>
    <message>
        <source>Rfcomm Bind</source>
        <translation>Rfcomm привязка</translation>
    </message>
    <message>
        <source>Bind device to a interface</source>
        <translation>Привязать устройство к интерфейсу</translation>
    </message>
</context>
<context>
    <name>RfcommDialogItemBase</name>
    <message>
        <source>Form2</source>
        <translation>Форма2</translation>
    </message>
    <message>
        <source>Mac</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Канал</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Заметки:</translation>
    </message>
</context>
</TS>

==> opie.i18n_anoncvs.handhelds.org_v1_2_3_.tar.gz: i18n/ru/bluetooth-manager.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>BlueBase</name>
    <message>
        <source>Bluetooth Manager</source>
        <translation>Менеджер Bluetooth</translation>
    </message>
    <message>
        <source>&lt;b&gt;Device name : &lt;/b&gt; Ipaq</source>
        <translation>&lt;b&gt;Имя устройства : &lt;/b&gt; Ipaq</translation>
    </message>
    <message>
        <source>MAC adress: </source>
        <translation>MAC адрес:</translation>
    </message>
    <message>
        <source>Class</source>
        <translation>Класс</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Тест</translation>
    </message>
    <message>
        <source>Changes were applied.</source>
        <translation>Изменения применены.</translation>
    </message>
    <message>
        <source>rescan sevices</source>
        <translation type="obsolete">просканировать сервисы</translation>
    </message>
    <message>
        <source>to group</source>
        <translation type="obsolete">в группу</translation>
    </message>
    <message>
        <source>delete</source>
        <translation type="obsolete">удалить</translation>
    </message>
    <message>
        <source>Test1:</source>
        <translation>Тест1:</translation>
    </message>
    <message>
        <source>no services found</source>
        <translation>сервисов не найдено</translation>
    </message>
    <message>
        <source>No connections found</source>
        <translation>Не найдено соединений</translation>
    </message>
    <message>
        <source>&amp;Rescan services</source>
        <translation>&amp;Просканировать сервисы</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Удалить</translation>
    </message>
</context>
<context>
    <name>BluetoothBase</name>
    <message>
        <source>Form1</source>
        <translation>Форма1</translation>
    </message>
    <message>
        <source>Devices</source>
        <translation>Устройства</translation>
    </message>
    <message>
        <source>Device Name</source>
        <translation>Имя устройства</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Онлайн</translation>
    </message>
    <message>
        <source>Scan for Devices</source>
        <translation type="obsolete">Просканировать устройства</translation>
    </message>
    <message>
        <source>Connections</source>
        <translation>Соединения</translation>
    </message>
    <message>
        <source>Connection type</source>
        <translation>Тип соединения</translation>
    </message>
    <message>
        <source>Signal</source>
        <translation>Сигнал</translation>
    </message>
    <message>
        <source>Config</source>
        <translation>Настройка</translation>
    </message>
    <message>
        <source>Bluetooh Basic Config</source>
        <translation type="obsolete">Основные настройки Bluetooth</translation>
    </message>
    <message>
        <source>Default Passkey</source>
        <translation>Ключ по умолчанию</translation>
    </message>
    <message>
        <source>enable authentification</source>
        <translation>разрешить аутентификацию</translation>
    </message>
    <message>
        <source>enable encryption</source>
        <translation>разрешить шифрование</translation>
    </message>
    <message>
        <source>Enable Page scan</source>
        <translation type="unfinished">Разрешить Page scan</translation>
    </message>
    <message>
        <source>Enable Inquiry scan</source>
        <translation type="unfinished">Разрешить Inquiry scan</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>Rfcomm Bind Table</source>
        <translation type="obsolete">Таблица привязок Rfcomm</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Status Label</source>
        <translation>Метка статуса</translation>
    </message>
    <message>
        <source>Bluetooth Basic Config</source>
        <translation>Основная настройка Bluetooth</translation>
    </message>
    <message>
        <source>&amp;Rescan Devices</source>
        <translation>&amp;Просканировать устройства</translation>
    </message>
    <message>
        <source>&amp;Edit RFCOMM Bind Table</source>
        <translation type="unfinished">П&amp;равка таблицы RFCOMM </translation>
    </message>
</context>
<context>
    <name>DeviceDialog</name>
    <message>
        <source>Form2</source>
        <translation>Форма2</translation>
    </message>
    <message>
        <source>Devicename</source>
        <translation type="obsolete">Имя устройства</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Сервицы</translation>
    </message>
    <message>
        <source>change settings</source>
        <translation type="obsolete">изменить настройки</translation>
    </message>
    <message>
        <source>active</source>
        <translation>включен</translation>
    </message>
    <message>
        <source>service name</source>
        <translation>имя сервиса</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Change device 
name</source>
        <translation type="obsolete">Изменить имя
устройства</translation>
    </message>
    <message>
        <source>Default PIN 
Code</source>
        <translation type="obsolete">PIN-код по
умолчанию</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>TextLabel9</source>
        <translation>ТекстМетка9</translation>
    </message>
    <message>
        <source>&amp;Apply Changes</source>
        <translation>&amp;Применить</translation>
    </message>
    <message>
        <source>Default PIN Code</source>
        <translation>PIN код по умолчанию</translation>
    </message>
    <message>
        <source>Change device name</source>
        <translation>Изменить имя устройства</translation>
    </message>
</context>
<context>
    <name>DunPopup</name>
    <message>
        <source>connect</source>
        <translation>подключить</translation>
    </message>
    <message>
        <source>connect+conf</source>
        <translation>подключить+конф</translation>
    </message>
    <message>
        <source>disconnect</source>
        <translation>отключить</translation>
    </message>
</context>
<context>
    <name>ObexDialog</name>
    <message>
        <source>beam files </source>
        <translation>отправить файлы</translation>
    </message>
    <message>
        <source>Which file should be beamed?</source>
        <translation>Какие файлы должны быть отправлены?</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Отправить</translation>
    </message>
</context>
<context>
    <name>OpieTooth::ScanDialog</name>
    <message>
        <source>Scan for devices</source>
        <translation>Искать устройства</translation>
    </message>
    <message>
        <source>Start scan</source>
        <translation>Начать поиск</translation>
    </message>
    <message>
        <source>Add Device</source>
        <translation>Добавить устройство</translation>
    </message>
    <message>
        <source>Stop scan</source>
        <translation>Остановить поиск</translation>
    </message>
</context>
<context>
    <name>PPPDialog</name>
    <message>
        <source>ppp connection </source>
        <translation>ppp соединение</translation>
    </message>
    <message>
        <source>Enter an ppp script name:</source>
        <translation>Введите имя скрипта ppp:</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Подключиться</translation>
    </message>
</context>
<context>
    <name>PanPopup</name>
    <message>
        <source>connect</source>
        <translation>подключить</translation>
    </message>
    <message>
        <source>connect+conf</source>
        <translation>подключить+конф</translation>
    </message>
    <message>
        <source>disconnect</source>
        <translation>отключить</translation>
    </message>
</context>
<context>
    <name>RfcommAssignDialogBase</name>
    <message>
        <source>Rfcomm Bind</source>
        <translation>Rfcomm привязка</translation>
    </message>
    <message>
        <source>Bind device to a interface</source>
        <translation>Привязать устройство к интерфейсу</translation>
    </message>
</context>
<context>
    <name>RfcommDialogItemBase</name>
    <message>
        <source>Form2</source>
        <translation>Форма2</translation>
    </message>
    <message>
        <source>Mac</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Канал</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Заметки:</translation>
    </message>
</context>
</TS>
